@@ -5,28 +5,48 @@ from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import sessionmaker
 from sqlalchemy import Column, Table
 from datetime import datetime
+import bcrypt
 
 from novatrace.connect import *
 
 Base = declarative_base()
 
+class User(Base):
+    __tablename__ = "users"
+    id = Column(Integer, primary_key=True)
+    username = Column(String(255), unique=True, nullable=False)
+    password_hash = Column(String(255), nullable=False)
+    is_active = Column(Boolean, default=True)
+    created_at = Column(DateTime, default=lambda: datetime.now(hora))
+    last_login = Column(DateTime, nullable=True)
+
+    def set_password(self, password):
+        """Hash and set password"""
+        self.password_hash = bcrypt.hashpw(password.encode('utf-8'), bcrypt.gensalt()).decode('utf-8')
+    
+    def check_password(self, password):
+        """Check if provided password matches hash"""
+        return bcrypt.checkpw(password.encode('utf-8'), self.password_hash.encode('utf-8'))
+
 class Session(Base):
     __tablename__ = "sessions"
     id = Column(Integer, primary_key=True)
     name = Column(String(255), unique=True)
-
+    project_id = Column(Integer, ForeignKey("projects.id"))  # Una sesión pertenece a un proyecto
     created_at = Column(DateTime, default=lambda: datetime.now(hora))
-    projects = relationship("Project", back_populates="session")
+    
+    project = relationship("Project", back_populates="sessions")
     traces = relationship("Trace", back_populates="session")
 
 class Project(Base):
     __tablename__ = "projects"
     id = Column(Integer, primary_key=True)
-    name = Column(String(255))
-    session_id = Column(Integer, ForeignKey("sessions.id"))
+    name = Column(String(255), unique=True)  # Los proyectos ahora son únicos
+    description = Column(String(500), nullable=True)  # Agregar descripción opcional
     created_at = Column(DateTime, default=lambda: datetime.now(hora))
+    updated_at = Column(DateTime, default=lambda: datetime.now(hora), onupdate=lambda: datetime.now(hora))
 
-    session = relationship("Session", back_populates="projects")
+    sessions = relationship("Session", back_populates="project")  # Un proyecto tiene muchas sesiones
     traces = relationship("Trace", back_populates="project")
 
 class TraceTypes(Base):
