@@ -18,11 +18,13 @@ _web_interface_registry = {
     'reflex_process': None,
     'container_name': 'novatrace-web',
     'instance_count': 0,
-    'interface_enabled': False
+    'interface_enabled': False,
+    'interface_started': False,
+    'engine': None  # Engine personalizado para compartir con la webapp
 }
 
 class NovaTrace:
-    def __init__(self, session_name: str, engine_url: str = None, time_zone: pytz.tzinfo = pytz.utc, interface: bool = True, interface_logs: bool = False):
+    def __init__(self, session_name: str, engine_url: str = None, time_zone: pytz.tzinfo = pytz.utc, interface: bool = True, debug: bool = False):
         """
         Init a new NovaTrace instance.
         Args:
@@ -30,7 +32,7 @@ class NovaTrace:
             engine_url (str, optional): SQLAlchemy engine URL. If not provided, defaults to the default engine.
             time_zone (pytz.tzinfo, optional): Time zone for timestamps. Defaults to UTC.
             interface (bool, optional): Whether to start the web interface. Defaults to True.
-            interface_logs (bool, optional): Whether to show detailed logs when interface is enabled. Defaults to False.
+            debug (bool, optional): Whether to show detailed logs. Defaults to False.
         Raises:
             ValueError: If metadata is not provided or incomplete.
         Returns:
@@ -42,7 +44,7 @@ class NovaTrace:
             # Original NovaTrace attributes
             self.time_zone = time_zone
             self.interface_enabled = interface
-            self.interface_logs = interface_logs
+            self.debug = debug
             self.reflex_process = None
             
             # Track this instance
@@ -57,10 +59,20 @@ class NovaTrace:
                 self._is_interface_owner = False
             
             if engine_url:
-                self.engine = create_engine(engine_url)
+                # Crear engine con configuraciones para manejo de reconexión
+                self.engine = create_engine(
+                    engine_url,
+                    pool_pre_ping=True,  # Verificar conexión antes de usar
+                    pool_recycle=3600,   # Reciclar conexiones cada hora
+                    connect_args={'connect_timeout': 10} if 'mysql' in engine_url else {}
+                )
             else:
                 self.engine = default_engine
             
+            # Almacenar el engine en el registro global para que la API lo pueda usar
+            if self._is_interface_owner:
+                _web_interface_registry['engine'] = self.engine
+            
             # Handle database migration for session_id column
             self._migrate_database_if_needed()
             
@@ -92,6 +104,11 @@ class NovaTrace:
             # Register cleanup only for database session (not web interface)
             self._register_cleanup_handlers()
             
+            # Initialize database with correct engine if this instance owns the interface
+            if self._is_interface_owner:
+                from .database.init_db import init_database
+                init_database(self.engine)
+            
             # Start interface if this instance owns it
             if self._is_interface_owner:
                 self._start_web_interface()
@@ -108,6 +125,7 @@ class NovaTrace:
             self.user_external_id = "guest_user"
             self.user_external_name = "Guest User"
             self.interface_enabled = False
+            self.debug = False
             self.reflex_process = None
             self._is_interface_owner = False
     
@@ -126,11 +144,29 @@ class NovaTrace:
         except Exception:
             pass  # Ignore errors in cleanup
     
+    def _handle_db_error(self, error_context="database operation"):
+        """Handle database errors with proper rollback and session refresh"""
+        try:
+            if hasattr(self, 'session') and self.session:
+                # Rollback any pending transaction
+                self.session.rollback()
+                # Close the current session
+                self.session.close()
+                # Create a new session
+                SessionLocal = sessionmaker(bind=self.engine)
+                self.session = SessionLocal()
+                if self.debug:
+                    print(f"NovaTrace: Database session refreshed after error in {error_context}")
+        except Exception as e:
+            if self.debug:
+                print(f"NovaTrace: Failed to refresh session after error: {e}")
+    
     def _migrate_database_if_needed(self):
-        """Handle database migration for new columns"""
+        """Handle database migration for new structure"""
         try:
-            # Check if session_id column exists in traces table
             inspector = inspect(self.engine)
+            
+            # Check if session_id column exists in traces table
             if 'traces' in inspector.get_table_names():
                 columns = [col['name'] for col in inspector.get_columns('traces')]
                 if 'session_id' not in columns:
@@ -139,6 +175,34 @@ class NovaTrace:
                         conn.execute(text("ALTER TABLE traces ADD COLUMN session_id INTEGER"))
                         conn.commit()
                         print("NovaTrace: Added session_id column to traces table")
+            
+            # Handle migration from old structure to new structure
+            if 'projects' in inspector.get_table_names() and 'sessions' in inspector.get_table_names():
+                project_columns = [col['name'] for col in inspector.get_columns('projects')]
+                session_columns = [col['name'] for col in inspector.get_columns('sessions')]
+                
+                # If projects still have session_id, we need to migrate
+                if 'session_id' in project_columns and 'project_id' not in session_columns:
+                    print("NovaTrace: Migrating database structure - Projects now own Sessions")
+                    
+                    with self.engine.connect() as conn:
+                        # Add project_id column to sessions
+                        conn.execute(text("ALTER TABLE sessions ADD COLUMN project_id INTEGER"))
+                        
+                        # Add description and updated_at to projects
+                        conn.execute(text("ALTER TABLE projects ADD COLUMN description VARCHAR(500)"))
+                        conn.execute(text("ALTER TABLE projects ADD COLUMN updated_at DATETIME"))
+                        
+                        # Make project names unique
+                        conn.execute(text("ALTER TABLE projects ADD CONSTRAINT unique_project_name UNIQUE (name)"))
+                        
+                        conn.commit()
+                        print("NovaTrace: Database migration completed")
+                        
+        except Exception as e:
+            if self.debug:
+                print(f"NovaTrace: Database migration warning: {e}")
+            pass  # Continue if migration fails
         except Exception as e:
             print(f"Warning: NovaTrace database migration failed: {e}")
     
@@ -152,6 +216,14 @@ class NovaTrace:
         if not self._is_interface_owner:
             return
         
+        # Prevent multiple starts
+        if _web_interface_registry['interface_started']:
+            if self.debug:
+                print("   💡 Web interface already started")
+            return
+        
+        _web_interface_registry['interface_started'] = True
+        
         current_dir = os.path.dirname(os.path.abspath(__file__))
         react_interface_dir = os.path.join(current_dir, "web_interface")
         
@@ -192,7 +264,7 @@ class NovaTrace:
                 image_name = "novatrace-web:latest"
                 build_cmd = ["docker", "build", "-t", image_name, "."]
                 
-                print("🚀 NovaTrace web interface starting...")
+                print("🚀 Iniciando NovaTrace con dashboard...")
                 
                 # Stop existing container if running
                 try:
@@ -218,16 +290,17 @@ class NovaTrace:
                         "docker", "run", "--rm", "--entrypoint", "ls", image_name, "/docker-entrypoint.sh"
                     ], capture_output=True, text=True)
                     if inspect_result.returncode != 0:
-                        print("   🔄 Detected old Docker image without dynamic port detection")
+                        if self.debug:
+                            print("   🔄 Detected old Docker image without dynamic port detection")
                         force_rebuild = True
                 
                 if not image_exists or force_rebuild:
-                    if force_rebuild:
+                    if force_rebuild and self.debug:
                         print("   Rebuilding Docker image (with dynamic port detection)...")
-                    else:
+                    elif self.debug:
                         print("   Building Docker image (first time)...")
                     
-                    if self.interface_logs:
+                    if self.debug:
                         print("   ✅ Docker build logs will be shown below:")
                         print("   " + "="*50)
                         build_process = subprocess.Popen(build_cmd, cwd=web_interface_dir)
@@ -245,8 +318,9 @@ class NovaTrace:
                         print("   ❌ Docker build failed")
                         return
                     
-                    print("   ✅ Docker image built successfully with dynamic port detection")
-                else:
+                    if self.debug:
+                        print("   ✅ Docker image built successfully with dynamic port detection")
+                elif self.debug:
                     print("   ✅ Using existing Docker image with dynamic port detection")
                     print("   💡 Image will automatically detect API port at startup")
                 
@@ -259,7 +333,15 @@ class NovaTrace:
                     image_name
                 ]
                 
-                docker_process = subprocess.Popen(run_cmd, cwd=web_interface_dir)
+                if self.debug:
+                    docker_process = subprocess.Popen(run_cmd, cwd=web_interface_dir)
+                else:
+                    docker_process = subprocess.Popen(
+                        run_cmd, 
+                        cwd=web_interface_dir,
+                        stdout=subprocess.DEVNULL,
+                        stderr=subprocess.DEVNULL
+                    )
                 docker_process.wait()
                 
                 # Store in global registry
@@ -274,12 +356,12 @@ class NovaTrace:
                 result = subprocess.run(check_cmd, capture_output=True, text=True)
                 
                 if result.returncode == 0 and "Up" in result.stdout:
-                    print("   ✅ Web interface running at: http://localhost:3000/")
-                    print("   📊 Dashboard: http://localhost:3000/")
-                    print("   📁 Projects: http://localhost:3000/projects")
-                    print("   ⚙️  Settings: http://localhost:3000/settings")
-                    if not self.interface_logs:
-                        print("   💡 Use interface_logs=True to see detailed logs")
+                    print("   Web interface running at: http://localhost:3000/")
+                    if self.debug:
+                        print("   📊 Dashboard: http://localhost:3000/")
+                        print("   📁 Projects: http://localhost:3000/projects")
+                        print("   ⚙️  Settings: http://localhost:3000/settings")
+                        print("   💡 Use debug=False to hide detailed logs")
                 else:
                     print("   ❌ Container failed to start")
                         
@@ -410,24 +492,24 @@ class NovaTrace:
                 api_port = self._find_available_port()
                 _web_interface_registry['api_port'] = api_port
                 
-                print("🔌 Starting NovaTrace API server...")
-                print(f"   API will be available at: http://localhost:{api_port}")
-                
-                if api_port != 4444:
-                    print(f"   💡 Using port {api_port} (4444 was occupied)")
+                if self.debug:
+                    print("🔌 Starting NovaTrace API server...")
+                    print(f"   API will be available at: http://localhost:{api_port}")
+                    
+                    if api_port != 4444:
+                        print(f"   💡 Using port {api_port} (4444 was occupied)")
                 
                 # Import and start FastAPI
                 import uvicorn
                 from .api import app
                 
-                # Configure uvicorn to run quietly unless interface_logs=True
-                if self.interface_logs:
+                # Configure uvicorn to run quietly unless debug=True
+                if self.debug:
                     log_level = "info"
                     print("   ✅ API logs will be shown below:")
                     print("   " + "="*50)
                 else:
                     log_level = "error"  # Only show errors
-                    print("   💡 Use interface_logs=True to see API logs")
                 
                 # Start the API server
                 uvicorn.run(
@@ -435,7 +517,7 @@ class NovaTrace:
                     host="0.0.0.0", 
                     port=api_port,
                     log_level=log_level,
-                    access_log=self.interface_logs
+                    access_log=self.debug
                 )
                 
             except Exception as e:
@@ -472,8 +554,8 @@ class NovaTrace:
                 env['PYTHONPATH'] = f"{novatrace_root}:{env.get('PYTHONPATH', '')}"
                     
                 # Run reflex run command with proper flags
-                if self.interface_logs:
-                    # Show all logs when interface_logs=True
+                if self.debug:
+                    # Show all logs when debug=True
                     print("🚀 NovaTrace legacy interface starting...")
                     print("   Frontend: http://localhost:3000")
                     print("   Backend:  http://localhost:8000")
@@ -487,7 +569,7 @@ class NovaTrace:
                         env=env
                     )
                 else:
-                    # Hide logs when interface_logs=False (default)
+                    # Hide logs when debug=False (default)
                     DEVNULL = subprocess.DEVNULL
                     self.reflex_process = subprocess.Popen(
                         ["reflex", "run", "--env", "dev"],
@@ -507,8 +589,8 @@ class NovaTrace:
                 
                 if self.reflex_process.poll() is None:
                     print("   ✅ App running at: http://localhost:3000/")
-                    if not self.interface_logs:
-                        print("   💡 Use interface_logs=True to see detailed logs")
+                    if not self.debug:
+                        print("   💡 Use debug=True to see detailed logs")
                 else:
                     print("   ❌ Process failed to start")
                         
@@ -535,9 +617,9 @@ class NovaTrace:
 
     def list_projects(self):
         """
-        List all projects in the current session.
+        List all projects (globally).
         """
-        return self.session.query(Project).filter_by(session_id=self.active_session.id).all()
+        return self.session.query(Project).all()
     
     def _find_available_port(self, preferred_ports=[4444, 4445, 4446, 4447]):
         """Find an available port from the preferred list"""
@@ -647,11 +729,11 @@ class NovaTrace:
 
     def create_project(self, project_name: str):
         """
-        Create a new project in the current session.
+        Create a new project and associate the current session with it.
         Args:
             project_name (str): Name of the project to be created.
         Raises:
-            ValueError: If a project with the same name already exists in the current session.
+            ValueError: If a project with the same name already exists.
         Returns:
             None
         """
@@ -660,24 +742,37 @@ class NovaTrace:
                 print("Warning: NovaTrace not properly initialized, cannot create project")
                 return
                 
-            existing_project = self.session.query(Project).filter_by(name=project_name, session_id=self.active_session.id).first()
+            # Buscar si el proyecto ya existe (globalmente, no por sesión)
+            existing_project = self.session.query(Project).filter_by(name=project_name).first()
             if existing_project:
-                print(f"Warning: Project '{project_name}' already exists in session '{self.active_session.name}'")
-                return
-            self.project = Project(name=project_name, session_id=self.active_session.id, created_at=datetime.now(self.time_zone))
+                # Si el proyecto existe, asociar la sesión actual a ese proyecto
+                self.project = existing_project
+                self.active_session.project_id = existing_project.id
+                print(f"Project '{project_name}' already exists. Associating current session to it.")
+            else:
+                # Crear nuevo proyecto
+                self.project = Project(
+                    name=project_name, 
+                    created_at=datetime.now(self.time_zone),
+                    updated_at=datetime.now(self.time_zone)
+                )
+                self.session.add(self.project)
+                self.session.commit()
+                
+                # Asociar la sesión actual al nuevo proyecto
+                self.active_session.project_id = self.project.id
 
-            self.session.add(self.project)
             self.session.commit()
         except Exception as e:
             print(f"Warning: NovaTrace create_project failed: {e}")
 
     def connect_to_project(self, project_name: str):
         """
-        Connect to an existing project in the current session.
+        Connect to an existing project and associate the current session with it.
         Args:
             project_name (str): Name of the project to connect to.
         Raises:
-            ValueError: If the project with the specified name does not exist in the current session.
+            ValueError: If the project with the specified name does not exist.
         Returns:
             Project: The project object if found.
         """
@@ -686,10 +781,17 @@ class NovaTrace:
                 print("Warning: NovaTrace not properly initialized, cannot connect to project")
                 return None
                 
-            self.project = self.session.query(Project).filter_by(name=project_name, session_id=self.active_session.id).first()
+            # Buscar proyecto globalmente (no por sesión)
+            self.project = self.session.query(Project).filter_by(name=project_name).first()
             if not self.project:
-                print(f"Warning: Project '{project_name}' not found in session '{self.active_session.name}'")
+                print(f"Warning: Project '{project_name}' not found")
                 return None
+                
+            # Asociar la sesión actual al proyecto
+            self.active_session.project_id = self.project.id
+            self.session.commit()
+            
+            print(f"Connected to project '{project_name}' with session '{self.active_session.name}'")
             return self.project
         except Exception as e:
             print(f"Warning: NovaTrace connect_to_project failed: {e}")
@@ -697,19 +799,103 @@ class NovaTrace:
 
     def _get_named_args(self, func, *args, **kwargs):
         """
-        Get named arguments from a function call.
+        Get named arguments from a function call with robust serialization.
         """
-        sig = inspect.signature(func)
-        bound_args = sig.bind(*args, **kwargs)
-        bound_args.apply_defaults()
+        try:
+            sig = py_inspect.signature(func)
+            bound_args = sig.bind(*args, **kwargs)
+            bound_args.apply_defaults()
 
-        named_args = {}
-        for name, value in bound_args.arguments.items():
-            named_args[name] = {
-                "type": type(value).__name__,
-                "value": value
-            }
-        return named_args
+            def serialize_value(value):
+                """Serialize a value with type information, handling complex objects safely"""
+                try:
+                    if value is None:
+                        return {"type": "NoneType", "value": None}
+                    elif isinstance(value, (str, int, float, bool)):
+                        return {"type": type(value).__name__, "value": value}
+                    elif isinstance(value, list):
+                        # Para listas, limitar el número de elementos serializados
+                        if len(value) <= 3:
+                            serialized_list = []
+                            for item in value:
+                                try:
+                                    serialized_list.append(serialize_value(item))
+                                except:
+                                    serialized_list.append({"type": "object", "value": str(item)[:100]})
+                            return {"type": "list", "value": serialized_list}
+                        else:
+                            # Para listas grandes, solo serializar los primeros elementos
+                            sample = []
+                            for item in value[:2]:
+                                try:
+                                    sample.append(serialize_value(item))
+                                except:
+                                    sample.append({"type": "object", "value": str(item)[:100]})
+                            return {"type": "list", "value": sample, "length": len(value), "truncated": True}
+                    elif isinstance(value, dict):
+                        # Para diccionarios, limitar el número de claves
+                        if len(value) <= 5:
+                            serialized_dict = {}
+                            for k, v in value.items():
+                                try:
+                                    serialized_dict[str(k)] = serialize_value(v)
+                                except:
+                                    serialized_dict[str(k)] = {"type": "object", "value": str(v)[:100]}
+                            return {"type": "dict", "value": serialized_dict}
+                        else:
+                            # Solo algunos elementos para diccionarios grandes
+                            serialized_dict = {}
+                            for k in list(value.keys())[:3]:
+                                try:
+                                    serialized_dict[str(k)] = serialize_value(value[k])
+                                except:
+                                    serialized_dict[str(k)] = {"type": "object", "value": str(value[k])[:100]}
+                            return {"type": "dict", "value": serialized_dict, "total_keys": len(value), "truncated": True}
+                    else:
+                        # Para otros tipos, convertir a string pero limitando el tamaño
+                        str_value = str(value)
+                        if len(str_value) > 500:
+                            str_value = str_value[:500] + "..."
+                        return {"type": type(value).__name__, "value": str_value}
+                except Exception as e:
+                    # Fallback seguro para cualquier objeto problemático
+                    return {"type": "unknown", "value": f"<Serialization error: {str(e)[:100]}>"}
+
+            named_args = {}
+            for name, value in bound_args.arguments.items():
+                named_args[name] = serialize_value(value)
+            
+            return named_args
+            
+        except Exception as e:
+            # Fallback más robusto que capture al menos los argumentos básicos
+            fallback_args = {}
+            try:
+                # Intentar capturar kwargs al menos
+                for key, value in kwargs.items():
+                    try:
+                        fallback_args[key] = {
+                            "type": type(value).__name__,
+                            "value": str(value)[:200] if not isinstance(value, (str, int, float, bool)) else value
+                        }
+                    except:
+                        fallback_args[key] = {"type": "unknown", "value": "<unable to serialize>"}
+                
+                # Si hay args posicionales, intentar capturarlos con nombres genéricos
+                if args:
+                    for i, arg in enumerate(args):
+                        try:
+                            fallback_args[f"arg_{i}"] = {
+                                "type": type(arg).__name__,
+                                "value": str(arg)[:200] if not isinstance(arg, (str, int, float, bool)) else arg
+                            }
+                        except:
+                            fallback_args[f"arg_{i}"] = {"type": "unknown", "value": "<unable to serialize>"}
+                            
+            except Exception:
+                fallback_args = {"error": f"Failed to parse arguments: {str(e)[:100]}"}
+            
+            return fallback_args
 
     def _extract_user_info(self, func, *args, **kwargs):
         """
@@ -780,7 +966,7 @@ class NovaTrace:
             return self.user_external_id, self.user_external_name
 
     def _get_trace_type_id(self, type_name):
-        """Get trace type ID by name."""
+        """Get trace type ID by name with proper error handling."""
         try:
             if not self.session:
                 return {"LLM": 1, "Agent": 2, "Tool": 3}.get(type_name, 1)
@@ -788,6 +974,9 @@ class NovaTrace:
             return trace_type.id if trace_type else {"LLM": 1, "Agent": 2, "Tool": 3}.get(type_name, 1)
         except Exception as e:
             print(f"Warning: NovaTrace _get_trace_type_id failed: {e}")
+            # Handle database error and refresh session
+            self._handle_db_error("_get_trace_type_id")
+            # Return fallback value
             return {"LLM": 1, "Agent": 2, "Tool": 3}.get(type_name, 1)
 
     def _log_trace(self, type_id: int, input_data, output_data, request_time, response_time,
@@ -843,6 +1032,40 @@ class NovaTrace:
             self.session.commit()
         except Exception as e:
             print(f"Warning: NovaTrace _log_trace failed: {e}")
+            # Handle database error and refresh session
+            self._handle_db_error("_log_trace")
+            
+            # Try to log again with fresh session (one retry)
+            try:
+                if self.session and self.project and self.active_session:
+                    duration = (response_time - request_time).total_seconds() * 1000  # ms
+                    trace = Trace(
+                        type_id=type_id,
+                        input_data=json.dumps(input_data, default=str),
+                        output_data=json.dumps(output_data, default=str),
+                        project_id=self.project.id,
+                        session_id=self.active_session.id,
+                        created_at=response_time,
+                        request_time=request_time,
+                        response_time=response_time,
+                        duration_ms=duration,
+                        input_tokens=input_tokens,
+                        output_tokens=output_tokens,
+                        model_provider=model_provider if model_provider else self.provider,
+                        model_name=model_name if model_name else self.model,
+                        model_input_cost=self.input_cost_per_million_tokens,
+                        model_output_cost=self.output_cost_per_million_tokens,
+                        call_cost = ((input_tokens * (self.input_cost_per_million_tokens/1000000)) + (output_tokens * (self.output_cost_per_million_tokens/1000000))),
+                        user_external_id=user_external_id,
+                        user_external_name=user_external_name
+                    )
+                    self.session.add(trace)
+                    self.session.commit()
+                    if self.debug:
+                        print("NovaTrace: Successfully logged trace after session refresh")
+            except Exception as retry_error:
+                if self.debug:
+                    print(f"NovaTrace: Failed to log trace after retry: {retry_error}")
 
     def llm(self, func):
         """
@@ -862,10 +1085,10 @@ class NovaTrace:
                 
                 result = func(*args, **kwargs)
                 response_time = datetime.now(self.time_zone)
-                try:
-                    _args = self._get_named_args(func, *args, **kwargs)
-                except Exception as e:
-                    _args = {"args": args}
+                
+                # Obtener argumentos con la nueva lógica mejorada
+                _args = self._get_named_args(func, *args, **kwargs)
+                
                 self._log_trace(self._get_trace_type_id("LLM"), {"args": _args},
                                 result, request_time, response_time,
                                 model_name=kwargs.get("model_name", self.model),
@@ -905,10 +1128,10 @@ class NovaTrace:
                 result = func(*args, **kwargs)
                 tokens = self.tokenizer(result)
                 response_time = datetime.now(self.time_zone)
-                try:
-                    _args = self._get_named_args(func, *args, **kwargs)
-                except Exception as e:
-                    _args = {"args": args}
+                
+                # Obtener argumentos con la nueva lógica mejorada
+                _args = self._get_named_args(func, *args, **kwargs)
+                
                 self._log_trace(self._get_trace_type_id("Agent"), {"args": _args}, 
                                 result, request_time, response_time,
                                 tokens.get("input_tokens", 0),
@@ -954,10 +1177,10 @@ class NovaTrace:
                     result_text = result
 
                 response_time = datetime.now(self.time_zone)
-                try:
-                    _args = self._get_named_args(func, *args, **kwargs)
-                except Exception as e:
-                    _args = {"args": args}
+                
+                # Obtener argumentos con la nueva lógica mejorada
+                _args = self._get_named_args(func, *args, **kwargs)
+                
                 self._log_trace(self._get_trace_type_id("Tool"), {"args": _args}, 
                                 str(result_text), request_time, response_time,
                                 user_external_id=user_id,
@@ -1005,7 +1228,7 @@ class NovaTrace:
             return
         
         try:
-            if getattr(self, 'interface_logs', False):
+            if getattr(self, 'debug', False):
                 print("\n🛑 NovaTrace cleanup starting...")
             
             # Close database session
@@ -1015,7 +1238,7 @@ class NovaTrace:
             # Stop API server
             api_port = _web_interface_registry.get('api_port')
             if api_port:
-                if getattr(self, 'interface_logs', False):
+                if getattr(self, 'debug', False):
                     print(f"   🔌 Stopping API server on port {api_port}")
                 self._kill_process_on_port(api_port)
                 _web_interface_registry['api_port'] = None
@@ -1035,7 +1258,7 @@ class NovaTrace:
                             "docker", "rm", container_name
                         ], capture_output=True, text=True)
                         
-                        if getattr(self, 'interface_logs', False):
+                        if getattr(self, 'debug', False):
                             print("   🐳 Docker container stopped")
                     except (subprocess.CalledProcessError, subprocess.TimeoutExpired, FileNotFoundError):
                         # Fallback to process termination (Reflex interface)
@@ -1051,22 +1274,23 @@ class NovaTrace:
                             if reflex_process.poll() is None:
                                 reflex_process.kill()
                             
-                            if getattr(self, 'interface_logs', False):
+                            if getattr(self, 'debug', False):
                                 print("   🔄 Reflex process terminated")
                     
                     _web_interface_registry['reflex_process'] = None
                 except Exception as e:
-                    if getattr(self, 'interface_logs', False):
+                    if getattr(self, 'debug', False):
                         print(f"   ⚠️  Interface cleanup warning: {e}")
             
             # Reset the registry
             _web_interface_registry['interface_enabled'] = False
+            _web_interface_registry['interface_started'] = False
             
-            if getattr(self, 'interface_logs', False):
+            if getattr(self, 'debug', False):
                 print("   ✅ NovaTrace cleanup completed")
             
         except Exception as e:
-            if getattr(self, 'interface_logs', False):
+            if getattr(self, 'debug', False):
                 print(f"   ⚠️  Cleanup warning: {str(e)}")
 
     def __del__(self):
